@@ -26,7 +26,7 @@
 #' }
 #' 
 
-MAPI_CheckData <- function(samples, metric, isMatrix=all((class(metric)=="matrix"), (nrow(metric)==ncol(metric)))) {
+MAPI_CheckData <- function(samples, metric, isMatrix=all(is.matrix(metric), (nrow(metric)==ncol(metric)))) {
   
 	message("Checking data...")
 	
@@ -38,7 +38,7 @@ MAPI_CheckData <- function(samples, metric, isMatrix=all((class(metric)=="matrix
 	data.table::setkey(my.samples, "ind")
 	
 	if (isMatrix) {
-		if (class(metric) != "matrix") {stop("'isMatrix' is true, so 'metric' parameter should be a matrix class with colnames and rownames")}
+		if (! is.matrix(metric)) {stop("'isMatrix' is true, so 'metric' parameter should be a matrix class with colnames and rownames")}
 		if (sum( colnames(metric) != rownames(metric) ) > 0) {
 			stop("Row names and column names are different") 
 		} else {
